# OBP_security_pillar

OBP_security_Pillar package can be used to get the compliance details of Operational Best Practices for AWS Well Architected Security Pillar.

Release Notes:
# v0.0.1
1. Added following compliance checks:
   - RdsAutomaticMinorVersionUpgradeEnabled
   - RdsInstancePublicAccessCheck
   - RdsSnapshotEncrypted
   - RdsSnapshotsPublicProhibited
   - RdsStorageEncrypted
   - S3BucketLoggingEnabled
   - S3BucketVersioningEnabled
